%define module rencode

Name:           python-%{module}
Version:        1.0.6
Release:        %mkrel 7
Summary:        Web safe object pickling/unpickling
License:        GPLv3+ and BSD
Group:          Development/Python
URL:            https://github.com/aresch/rencode
Source0:        https://files.pythonhosted.org/packages/source/l/%{module}/%{module}-%{version}.tar.gz
# PyPi source tarball doesn't contain the .pyx file. This is the .pyx file
# corresponding to tag 1.0.6. Updating the version will also require this file
# to be updated.
# https://github.com/aresch/rencode/issues/22
Source1:        https://raw.githubusercontent.com/aresch/rencode/53d72ac53d9df007aad3a980f049a80d81836619/rencode/rencode.pyx
# The rencode package through 1.0.6 for Python allows an infinite loop in typecode decoding (such as via ;\x2f\x7f), enabling a remote attack that consumes CPU and memory.
Patch0:         python-rencode-fix-CVE-2021-40839.patch
BuildRequires:  gcc

BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-devel
BuildRequires:  python3dist(cython)


%description
The rencode module is a modified version of bencode from the
BitTorrent project.  For complex, heterogeneous data structures with
many small elements, r-encodings take up significantly less space than
b-encodings.

%package -n     python3-%{module}
Summary:        Web safe object pickling/unpickling
Group:          Development/Python
%{?python_provide:%python_provide python3-%{module}}

%description -n python3-%{module}
The rencode module is a modified version of bencode from the
BitTorrent project.  For complex, heterogeneous data structures with
many small elements, r-encodings take up significantly less space than
b-encodings.

%prep
%setup -n %{module}-%{version}
cp -a %{SOURCE1} ./rencode
%patch 0 -p1

# Make sure we rebuild the module
rm -f ./rencode/rencode.c

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files rencode

%check
pushd tests
PYTHONPATH=%{buildroot}%{python3_sitearch} %{__python3} test_rencode.py
PYTHONPATH=%{buildroot}%{python3_sitearch} %{__python3} timetest.py
popd

%files -n python3-%{module} -f %{pyproject_files}
%doc README.md
%license COPYING


%changelog
* Fri Dec 15 2023 papoteur <papoteur> 1.0.6-7.mga10
+ Revision: 2018207
- rebuild for python 3.12
- adapt to pyproject

* Mon May 02 2022 papoteur <papoteur> 1.0.6-6.mga9
+ Revision: 1855514
- fix CVE-2021-40839

* Tue Mar 29 2022 umeabot <umeabot> 1.0.6-5.mga9
+ Revision: 1831654
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 mrambo3501 <mrambo3501> 1.0.6-4.mga9
+ Revision: 1775154
- rebuild for python-3.10

* Mon Mar 22 2021 daviddavid <daviddavid> 1.0.6-3.mga9
+ Revision: 1707316
- rebuild for python 3.9
- remove bundled egg-info

* Sun Feb 16 2020 umeabot <umeabot> 1.0.6-2.mga8
+ Revision: 1533365
- Mageia 8 Mass Rebuild

* Fri Sep 20 2019 daviddavid <daviddavid> 1.0.6-1.mga8
+ Revision: 1444092
- initial package python-rencode

